pub async fn authentication_check_retrieve(
configuration: &Configuration,
) -> Result<HashMap<String, Value>, Error<AuthenticationCheckRetrieveError>>Expand description
Return the user making the request, if authenticated successfully.
pub async fn authentication_check_retrieve(
configuration: &Configuration,
) -> Result<HashMap<String, Value>, Error<AuthenticationCheckRetrieveError>>Return the user making the request, if authenticated successfully.