is_generic_fk

Function is_generic_fk 

pub fn is_generic_fk(model: &str, field: &str) -> bool
Returns true if field on model is a generic foreign key whose value must be encoded as a content-type reference rather than a bare id.