pub struct BriefInterface {
pub id: Option<i32>,
pub url: Option<String>,
pub display: Option<String>,
pub device: Box<BriefDevice>,
pub name: String,
pub description: Option<String>,
pub cable: Option<Option<Box<BriefCable>>>,
pub _occupied: Option<bool>,
}Expand description
BriefInterface : Adds an owner field for models which have a ForeignKey to users.Owner.
Fields
id: Option<i32>url: Option<String>display: Option<String>device: Box<BriefDevice>name: Stringdescription: Option<String>cable: Option<Option<Box<BriefCable>>>_occupied: Option<bool>Implementations
Sourceimpl BriefInterface
impl BriefInterface
Sourcepub fn new(device: BriefDevice, name: String) -> BriefInterface
pub fn new(device: BriefDevice, name: String) -> BriefInterface
Adds an owner field for models which have a ForeignKey to users.Owner.