pub struct BriefOwnerGroup {
pub id: Option<i32>,
pub url: Option<String>,
pub display: Option<String>,
pub name: String,
pub description: Option<String>,
}Expand description
BriefOwnerGroup : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: Option<i32>url: Option<String>display: Option<String>name: Stringdescription: Option<String>Implementations
Sourceimpl BriefOwnerGroup
impl BriefOwnerGroup
Sourcepub fn new(name: String) -> BriefOwnerGroup
pub fn new(name: String) -> BriefOwnerGroup
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)