Module bulk_event_rule_request

Module bulk_event_rule_request 

Structs

BulkEventRuleRequest
BulkEventRuleRequest : Adds an owner field for models which have a ForeignKey to users.Owner.

Enums

ActionType
webhook - Webhook * script - Script * notification - Notification
EventTypes
The types of event which will trigger this rule.