pub struct BulkEventRuleRequest {Show 13 fields
pub id: i32,
pub object_types: Vec<String>,
pub name: String,
pub enabled: Option<bool>,
pub event_types: Vec<EventTypes>,
pub conditions: Option<Option<Value>>,
pub action_type: ActionType,
pub action_object_type: String,
pub action_object_id: Option<Option<i64>>,
pub description: Option<String>,
pub custom_fields: Option<HashMap<String, Value>>,
pub owner: Option<Option<Box<AsnRangeRequestOwner>>>,
pub tags: Option<Vec<NestedTagRequest>>,
}Expand description
BulkEventRuleRequest : Adds an owner field for models which have a ForeignKey to users.Owner.
Fields
id: i32object_types: Vec<String>name: Stringenabled: Option<bool>event_types: Vec<EventTypes>The types of event which will trigger this rule.
conditions: Option<Option<Value>>A set of conditions which determine whether the event will be generated.
action_type: ActionTypewebhook- Webhook *script- Script *notification- Notification
action_object_type: Stringaction_object_id: Option<Option<i64>>description: Option<String>custom_fields: Option<HashMap<String, Value>>owner: Option<Option<Box<AsnRangeRequestOwner>>>Implementations
Sourceimpl BulkEventRuleRequest
impl BulkEventRuleRequest
Sourcepub fn new(
id: i32,
object_types: Vec<String>,
name: String,
event_types: Vec<EventTypes>,
action_type: ActionType,
action_object_type: String,
) -> BulkEventRuleRequest
pub fn new( id: i32, object_types: Vec<String>, name: String, event_types: Vec<EventTypes>, action_type: ActionType, action_object_type: String, ) -> BulkEventRuleRequest
Adds an owner field for models which have a ForeignKey to users.Owner.