pub struct BulkImageAttachmentRequest {
pub id: i32,
pub object_type: String,
pub object_id: i64,
pub name: Option<String>,
pub image: PathBuf,
pub description: Option<String>,
}Expand description
BulkImageAttachmentRequest : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: i32object_type: Stringobject_id: i64name: Option<String>image: PathBufdescription: Option<String>Implementations
Sourceimpl BulkImageAttachmentRequest
impl BulkImageAttachmentRequest
Sourcepub fn new(
id: i32,
object_type: String,
object_id: i64,
image: PathBuf,
) -> BulkImageAttachmentRequest
pub fn new( id: i32, object_type: String, object_id: i64, image: PathBuf, ) -> BulkImageAttachmentRequest
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)