pub struct BulkNotificationRequest {
pub id: i32,
pub object_type: String,
pub object_id: i64,
pub user: Box<BookmarkRequestUser>,
pub read: Option<Option<String>>,
pub event_type: EventType,
}Expand description
BulkNotificationRequest : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: i32object_type: Stringobject_id: i64user: Box<BookmarkRequestUser>read: Option<Option<String>>event_type: EventTypeobject_created- Object created *object_updated- Object updated *object_deleted- Object deleted *job_started- Job started *job_completed- Job completed *job_failed- Job failed *job_errored- Job errored
Implementations
Sourceimpl BulkNotificationRequest
impl BulkNotificationRequest
Sourcepub fn new(
id: i32,
object_type: String,
object_id: i64,
user: BookmarkRequestUser,
event_type: EventType,
) -> BulkNotificationRequest
pub fn new( id: i32, object_type: String, object_id: i64, user: BookmarkRequestUser, event_type: EventType, ) -> BulkNotificationRequest
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)