pub struct ConfigTemplate {Show 22 fields
pub id: Option<i32>,
pub url: Option<String>,
pub display_url: Option<String>,
pub display: Option<String>,
pub name: String,
pub description: Option<String>,
pub environment_params: Option<Option<Value>>,
pub template_code: String,
pub mime_type: Option<String>,
pub file_name: Option<String>,
pub file_extension: Option<String>,
pub as_attachment: Option<bool>,
pub debug: Option<bool>,
pub data_source: Option<Box<BriefDataSource>>,
pub data_path: Option<String>,
pub data_file: Option<Box<BriefDataFile>>,
pub auto_sync_enabled: Option<bool>,
pub data_synced: Option<Option<String>>,
pub owner: Option<Option<Box<BriefOwner>>>,
pub tags: Option<Vec<NestedTag>>,
pub created: Option<Option<String>>,
pub last_updated: Option<Option<String>>,
}Expand description
ConfigTemplate : Adds an owner field for models which have a ForeignKey to users.Owner.
Fields
id: Option<i32>url: Option<String>display_url: Option<String>display: Option<String>name: Stringdescription: Option<String>environment_params: Option<Option<Value>>Any additional parameters (https://jinja.palletsprojects.com/en/stable/api/#jinja2.Environment) to pass when constructing the Jinja environment
template_code: StringJinja template code.
mime_type: Option<String>Defaults to text/plain; charset=utf-8
file_name: Option<String>Filename to give to the rendered export file
file_extension: Option<String>Extension to append to the rendered filename
as_attachment: Option<bool>Download file as attachment
debug: Option<bool>Enable verbose error output when rendering this template. Not recommended for production use.
data_source: Option<Box<BriefDataSource>>data_path: Option<String>Path to remote file (relative to data source root)
data_file: Option<Box<BriefDataFile>>auto_sync_enabled: Option<bool>Enable automatic synchronization of data when the data file is updated
data_synced: Option<Option<String>>owner: Option<Option<Box<BriefOwner>>>created: Option<Option<String>>last_updated: Option<Option<String>>Implementations
Sourceimpl ConfigTemplate
impl ConfigTemplate
Sourcepub fn new(name: String, template_code: String) -> ConfigTemplate
pub fn new(name: String, template_code: String) -> ConfigTemplate
Adds an owner field for models which have a ForeignKey to users.Owner.