Module custom_link_request

Module custom_link_request 

Structs

CustomLinkRequest
CustomLinkRequest : Adds an owner field for models which have a ForeignKey to users.Owner.

Enums

ButtonClass
The class of the first link in a group will be used for the dropdown button * default - Default * blue - Blue * indigo - Indigo * purple - Purple * pink - Pink * red - Red * orange - Orange * yellow - Yellow * green - Green * teal - Teal * cyan - Cyan * gray - Gray * black - Black * white - White * ghost-dark - Link