Skip to main contentModule extras_custom_fields_create_request
Source - ExtrasCustomFieldsCreateRequest
- FilterLogic
- Loose matches any instance of a given string; exact matches the entire field. *
disabled - Disabled * loose - Loose * exact - Exact - RHashType
- The type of data this custom field holds *
text - Text * longtext - Text (long) * integer - Integer * decimal - Decimal * boolean - Boolean (true/false) * date - Date * datetime - Date & time * url - URL * json - JSON * select - Selection * multiselect - Multiple selection * object - Object * multiobject - Multiple objects - UiEditable
- Specifies whether the custom field value can be edited in the UI *
yes - Yes * no - No * hidden - Hidden - UiVisible
- Specifies whether the custom field is displayed in the UI *
always - Always * if-set - If set * hidden - Hidden