Module extras_custom_links_create_request

Module extras_custom_links_create_request 

Structs

ExtrasCustomLinksCreateRequest

Enums

ButtonClass
The class of the first link in a group will be used for the dropdown button * default - Default * blue - Blue * indigo - Indigo * purple - Purple * pink - Pink * red - Red * orange - Orange * yellow - Yellow * green - Green * teal - Teal * cyan - Cyan * gray - Gray * black - Black * white - White * ghost-dark - Link