pub struct Owner {
pub id: Option<i32>,
pub url: Option<String>,
pub display_url: Option<String>,
pub display: Option<String>,
pub name: String,
pub group: Option<Box<BriefOwnerGroup>>,
pub description: Option<String>,
pub user_groups: Option<Vec<Group>>,
pub users: Option<Vec<User>>,
}Expand description
Owner : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: Option<i32>url: Option<String>display_url: Option<String>display: Option<String>name: Stringgroup: Option<Box<BriefOwnerGroup>>description: Option<String>user_groups: Option<Vec<Group>>users: Option<Vec<User>>Implementations
Sourceimpl Owner
impl Owner
Sourcepub fn new(name: String, group: Option<BriefOwnerGroup>) -> Owner
pub fn new(name: String, group: Option<BriefOwnerGroup>) -> Owner
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)