pub struct OwnerGroup {
pub id: Option<i32>,
pub url: Option<String>,
pub display_url: Option<String>,
pub display: Option<String>,
pub name: String,
pub description: Option<String>,
pub member_count: Option<i64>,
}Expand description
OwnerGroup : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: Option<i32>url: Option<String>display_url: Option<String>display: Option<String>name: Stringdescription: Option<String>member_count: Option<i64>Implementations
Sourceimpl OwnerGroup
impl OwnerGroup
Sourcepub fn new(name: String) -> OwnerGroup
pub fn new(name: String) -> OwnerGroup
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)