pub struct OwnerGroupRequest {
pub name: String,
pub description: Option<String>,
}Expand description
OwnerGroupRequest : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
name: Stringdescription: Option<String>Implementations
Sourceimpl OwnerGroupRequest
impl OwnerGroupRequest
Sourcepub fn new(name: String) -> OwnerGroupRequest
pub fn new(name: String) -> OwnerGroupRequest
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)