pub struct PatchedBulkBookmarkRequest {
pub id: i32,
pub object_type: Option<String>,
pub object_id: Option<i64>,
pub user: Option<Box<BookmarkRequestUser>>,
}Expand description
PatchedBulkBookmarkRequest : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: i32object_type: Option<String>object_id: Option<i64>user: Option<Box<BookmarkRequestUser>>Implementations
Sourceimpl PatchedBulkBookmarkRequest
impl PatchedBulkBookmarkRequest
Sourcepub fn new(id: i32) -> PatchedBulkBookmarkRequest
pub fn new(id: i32) -> PatchedBulkBookmarkRequest
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)