pub struct PatchedBulkEventRuleRequest {Show 13 fields
pub id: i32,
pub object_types: Option<Vec<String>>,
pub name: Option<String>,
pub enabled: Option<bool>,
pub event_types: Option<Vec<EventTypes>>,
pub conditions: Option<Option<Value>>,
pub action_type: Option<ActionType>,
pub action_object_type: Option<String>,
pub action_object_id: Option<Option<i64>>,
pub description: Option<String>,
pub custom_fields: Option<HashMap<String, Value>>,
pub owner: Option<Option<Box<AsnRangeRequestOwner>>>,
pub tags: Option<Vec<NestedTagRequest>>,
}Expand description
PatchedBulkEventRuleRequest : Adds an owner field for models which have a ForeignKey to users.Owner.
Fields
id: i32object_types: Option<Vec<String>>name: Option<String>enabled: Option<bool>event_types: Option<Vec<EventTypes>>The types of event which will trigger this rule.
conditions: Option<Option<Value>>A set of conditions which determine whether the event will be generated.
action_type: Option<ActionType>webhook- Webhook *script- Script *notification- Notification
action_object_type: Option<String>action_object_id: Option<Option<i64>>description: Option<String>custom_fields: Option<HashMap<String, Value>>owner: Option<Option<Box<AsnRangeRequestOwner>>>Implementations
Sourceimpl PatchedBulkEventRuleRequest
impl PatchedBulkEventRuleRequest
Sourcepub fn new(id: i32) -> PatchedBulkEventRuleRequest
pub fn new(id: i32) -> PatchedBulkEventRuleRequest
Adds an owner field for models which have a ForeignKey to users.Owner.