pub struct PatchedBulkFrontPortTemplateRequest {
pub id: i32,
pub device_type: Option<Option<Box<BulkConsolePortTemplateRequestDeviceType>>>,
pub module_type: Option<Option<Box<BulkConsolePortTemplateRequestModuleType>>>,
pub name: Option<String>,
pub label: Option<String>,
pub type: Option<RHashType>,
pub color: Option<Box<BulkCableRequestColor>>,
pub positions: Option<i32>,
pub rear_ports: Option<Vec<FrontPortTemplateMappingRequest>>,
pub description: Option<String>,
}Expand description
PatchedBulkFrontPortTemplateRequest : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: i32device_type: Option<Option<Box<BulkConsolePortTemplateRequestDeviceType>>>module_type: Option<Option<Box<BulkConsolePortTemplateRequestModuleType>>>name: Option<String>{module} is accepted as a substitution for the module bay position when attached to a module type.
label: Option<String>Physical label
type: Option<RHashType>8p8c- 8P8C *8p6c- 8P6C *8p4c- 8P4C *8p2c- 8P2C *6p6c- 6P6C *6p4c- 6P4C *6p2c- 6P2C *4p4c- 4P4C *4p2c- 4P2C *gg45- GG45 *tera-4p- TERA 4P *tera-2p- TERA 2P *tera-1p- TERA 1P *110-punch- 110 Punch *bnc- BNC *f- F Connector *n- N Connector *mrj21- MRJ21 *fc- FC *fc-pc- FC/PC *fc-upc- FC/UPC *fc-apc- FC/APC *lc- LC *lc-pc- LC/PC *lc-upc- LC/UPC *lc-apc- LC/APC *mu- MU *mu-pc- MU/PC *mu-upc- MU/UPC *mu-apc- MU/APC *lsh- LSH *lsh-pc- LSH/PC *lsh-upc- LSH/UPC *lsh-apc- LSH/APC *lx5- LX.5 *lx5-pc- LX.5/PC *lx5-upc- LX.5/UPC *lx5-apc- LX.5/APC *mpo- MPO *mtrj- MTRJ *sc- SC *sc-pc- SC/PC *sc-upc- SC/UPC *sc-apc- SC/APC *st- ST *cs- CS *sn- SN *mdc- MDC *sma-905- SMA 905 *sma-906- SMA 906 *urm-p2- URM-P2 *urm-p4- URM-P4 *urm-p8- URM-P8 *splice- Splice *usb-a- USB Type A *usb-b- USB Type B *usb-c- USB Type C *usb-mini-a- USB Mini A *usb-mini-b- USB Mini B *usb-micro-a- USB Micro A *usb-micro-b- USB Micro B *usb-micro-ab- USB Micro AB *other- Other
color: Option<Box<BulkCableRequestColor>>positions: Option<i32>rear_ports: Option<Vec<FrontPortTemplateMappingRequest>>description: Option<String>Implementations
Sourceimpl PatchedBulkFrontPortTemplateRequest
impl PatchedBulkFrontPortTemplateRequest
Sourcepub fn new(id: i32) -> PatchedBulkFrontPortTemplateRequest
pub fn new(id: i32) -> PatchedBulkFrontPortTemplateRequest
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)