pub struct PatchedBulkImageAttachmentRequest {
pub id: i32,
pub object_type: Option<String>,
pub object_id: Option<i64>,
pub name: Option<String>,
pub image: Option<PathBuf>,
pub description: Option<String>,
}Expand description
PatchedBulkImageAttachmentRequest : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: i32object_type: Option<String>object_id: Option<i64>name: Option<String>image: Option<PathBuf>description: Option<String>Implementations
Sourceimpl PatchedBulkImageAttachmentRequest
impl PatchedBulkImageAttachmentRequest
Sourcepub fn new(id: i32) -> PatchedBulkImageAttachmentRequest
pub fn new(id: i32) -> PatchedBulkImageAttachmentRequest
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)