pub struct PatchedBulkInventoryItemRequest {Show 18 fields
pub id: i32,
pub device: Option<Box<BriefInterfaceRequestDevice>>,
pub parent: Option<Option<i32>>,
pub name: Option<String>,
pub label: Option<String>,
pub status: Option<Status>,
pub role: Option<Option<Box<BulkInventoryItemRequestRole>>>,
pub manufacturer: Option<Option<Box<BulkInventoryItemRequestManufacturer>>>,
pub part_id: Option<String>,
pub serial: Option<String>,
pub asset_tag: Option<Option<String>>,
pub discovered: Option<bool>,
pub description: Option<String>,
pub component_type: Option<Option<String>>,
pub component_id: Option<Option<i64>>,
pub owner: Option<Option<Box<AsnRangeRequestOwner>>>,
pub tags: Option<Vec<NestedTagRequest>>,
pub custom_fields: Option<HashMap<String, Value>>,
}Expand description
PatchedBulkInventoryItemRequest : Adds an owner field for models which have a ForeignKey to users.Owner.
Fields
id: i32device: Option<Box<BriefInterfaceRequestDevice>>parent: Option<Option<i32>>name: Option<String>label: Option<String>Physical label
status: Option<Status>offline- Offline *active- Active *planned- Planned *staged- Staged *failed- Failed *decommissioning- Decommissioning
role: Option<Option<Box<BulkInventoryItemRequestRole>>>manufacturer: Option<Option<Box<BulkInventoryItemRequestManufacturer>>>part_id: Option<String>Manufacturer-assigned part identifier
serial: Option<String>asset_tag: Option<Option<String>>A unique tag used to identify this item
discovered: Option<bool>This item was automatically discovered
description: Option<String>component_type: Option<Option<String>>component_id: Option<Option<i64>>owner: Option<Option<Box<AsnRangeRequestOwner>>>custom_fields: Option<HashMap<String, Value>>Implementations
Sourceimpl PatchedBulkInventoryItemRequest
impl PatchedBulkInventoryItemRequest
Sourcepub fn new(id: i32) -> PatchedBulkInventoryItemRequest
pub fn new(id: i32) -> PatchedBulkInventoryItemRequest
Adds an owner field for models which have a ForeignKey to users.Owner.