pub struct PatchedBulkModuleBayRequest {
pub id: i32,
pub device: Option<Box<BriefInterfaceRequestDevice>>,
pub module: Option<Option<Box<BulkConsolePortRequestModule>>>,
pub name: Option<String>,
pub label: Option<String>,
pub position: Option<String>,
pub enabled: Option<bool>,
pub description: Option<String>,
pub installed_module: Option<Option<Box<BulkConsolePortRequestModule>>>,
pub owner: Option<Option<Box<AsnRangeRequestOwner>>>,
pub tags: Option<Vec<NestedTagRequest>>,
pub custom_fields: Option<HashMap<String, Value>>,
}Expand description
PatchedBulkModuleBayRequest : Adds an owner field for models which have a ForeignKey to users.Owner.
Fields
id: i32device: Option<Box<BriefInterfaceRequestDevice>>module: Option<Option<Box<BulkConsolePortRequestModule>>>name: Option<String>label: Option<String>Physical label
position: Option<String>Identifier to reference when renaming installed components
enabled: Option<bool>description: Option<String>installed_module: Option<Option<Box<BulkConsolePortRequestModule>>>owner: Option<Option<Box<AsnRangeRequestOwner>>>custom_fields: Option<HashMap<String, Value>>Implementations
Sourceimpl PatchedBulkModuleBayRequest
impl PatchedBulkModuleBayRequest
Sourcepub fn new(id: i32) -> PatchedBulkModuleBayRequest
pub fn new(id: i32) -> PatchedBulkModuleBayRequest
Adds an owner field for models which have a ForeignKey to users.Owner.