pub struct PatchedBulkModuleBayTemplateRequest {
pub id: i32,
pub device_type: Option<Option<Box<BulkConsolePortTemplateRequestDeviceType>>>,
pub module_type: Option<Option<Box<BulkConsolePortTemplateRequestModuleType>>>,
pub name: Option<String>,
pub label: Option<String>,
pub position: Option<String>,
pub enabled: Option<bool>,
pub description: Option<String>,
}Expand description
PatchedBulkModuleBayTemplateRequest : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: i32device_type: Option<Option<Box<BulkConsolePortTemplateRequestDeviceType>>>module_type: Option<Option<Box<BulkConsolePortTemplateRequestModuleType>>>name: Option<String>{module} is accepted as a substitution for the module bay position when attached to a module type.
label: Option<String>Physical label
position: Option<String>Identifier to reference when renaming installed components
enabled: Option<bool>description: Option<String>Implementations
Sourceimpl PatchedBulkModuleBayTemplateRequest
impl PatchedBulkModuleBayTemplateRequest
Sourcepub fn new(id: i32) -> PatchedBulkModuleBayTemplateRequest
pub fn new(id: i32) -> PatchedBulkModuleBayTemplateRequest
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)