pub struct PatchedBulkNotificationRequest {
pub id: i32,
pub object_type: Option<String>,
pub object_id: Option<i64>,
pub user: Option<Box<BookmarkRequestUser>>,
pub read: Option<Option<String>>,
pub event_type: Option<EventType>,
}Expand description
PatchedBulkNotificationRequest : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: i32object_type: Option<String>object_id: Option<i64>user: Option<Box<BookmarkRequestUser>>read: Option<Option<String>>event_type: Option<EventType>object_created- Object created *object_updated- Object updated *object_deleted- Object deleted *job_started- Job started *job_completed- Job completed *job_failed- Job failed *job_errored- Job errored
Implementations
Sourceimpl PatchedBulkNotificationRequest
impl PatchedBulkNotificationRequest
Sourcepub fn new(id: i32) -> PatchedBulkNotificationRequest
pub fn new(id: i32) -> PatchedBulkNotificationRequest
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)