pub struct PatchedBulkObjectPermissionRequest {
pub id: i32,
pub name: Option<String>,
pub description: Option<String>,
pub enabled: Option<bool>,
pub object_types: Option<Vec<String>>,
pub actions: Option<Vec<String>>,
pub constraints: Option<Option<Value>>,
pub groups: Option<Vec<i32>>,
pub users: Option<Vec<i32>>,
}Expand description
PatchedBulkObjectPermissionRequest : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: i32name: Option<String>description: Option<String>enabled: Option<bool>object_types: Option<Vec<String>>actions: Option<Vec<String>>The list of actions granted by this permission
constraints: Option<Option<Value>>Queryset filter matching the applicable objects of the selected type(s)
groups: Option<Vec<i32>>users: Option<Vec<i32>>Implementations
Sourceimpl PatchedBulkObjectPermissionRequest
impl PatchedBulkObjectPermissionRequest
Sourcepub fn new(id: i32) -> PatchedBulkObjectPermissionRequest
pub fn new(id: i32) -> PatchedBulkObjectPermissionRequest
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)