pub struct PatchedBulkOwnerRequest {
pub id: i32,
pub name: Option<String>,
pub group: Option<Option<Box<BulkOwnerRequestGroup>>>,
pub description: Option<String>,
pub user_groups: Option<Vec<i32>>,
pub users: Option<Vec<i32>>,
}Expand description
PatchedBulkOwnerRequest : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: i32name: Option<String>group: Option<Option<Box<BulkOwnerRequestGroup>>>description: Option<String>user_groups: Option<Vec<i32>>users: Option<Vec<i32>>Implementations
Sourceimpl PatchedBulkOwnerRequest
impl PatchedBulkOwnerRequest
Sourcepub fn new(id: i32) -> PatchedBulkOwnerRequest
pub fn new(id: i32) -> PatchedBulkOwnerRequest
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)