pub struct PatchedBulkPowerOutletRequest {Show 15 fields
pub id: i32,
pub device: Option<Box<BriefInterfaceRequestDevice>>,
pub module: Option<Option<Box<BulkConsolePortRequestModule>>>,
pub name: Option<String>,
pub label: Option<String>,
pub type: Option<Option<RHashType>>,
pub status: Option<Status>,
pub color: Option<Box<BulkCableRequestColor>>,
pub power_port: Option<Option<Box<BulkPowerOutletRequestPowerPort>>>,
pub feed_leg: Option<Option<FeedLeg>>,
pub description: Option<String>,
pub mark_connected: Option<bool>,
pub owner: Option<Option<Box<AsnRangeRequestOwner>>>,
pub tags: Option<Vec<NestedTagRequest>>,
pub custom_fields: Option<HashMap<String, Value>>,
}Expand description
PatchedBulkPowerOutletRequest : Adds an owner field for models which have a ForeignKey to users.Owner.
Fields
id: i32device: Option<Box<BriefInterfaceRequestDevice>>module: Option<Option<Box<BulkConsolePortRequestModule>>>name: Option<String>label: Option<String>Physical label
type: Option<Option<RHashType>>iec-60320-c5- C5 *iec-60320-c7- C7 *iec-60320-c13- C13 *iec-60320-c15- C15 *iec-60320-c17- C17 *iec-60320-c19- C19 *iec-60320-c21- C21 *iec-60309-p-n-e-4h- P+N+E 4H *iec-60309-p-n-e-6h- P+N+E 6H *iec-60309-p-n-e-9h- P+N+E 9H *iec-60309-2p-e-4h- 2P+E 4H *iec-60309-2p-e-6h- 2P+E 6H *iec-60309-2p-e-9h- 2P+E 9H *iec-60309-3p-e-4h- 3P+E 4H *iec-60309-3p-e-6h- 3P+E 6H *iec-60309-3p-e-9h- 3P+E 9H *iec-60309-3p-n-e-4h- 3P+N+E 4H *iec-60309-3p-n-e-6h- 3P+N+E 6H *iec-60309-3p-n-e-9h- 3P+N+E 9H *iec-60906-1- IEC 60906-1 *nbr-14136-10a- 2P+T 10A (NBR 14136) *nbr-14136-20a- 2P+T 20A (NBR 14136) *nema-1-15r- NEMA 1-15R *nema-5-15r- NEMA 5-15R *nema-5-20r- NEMA 5-20R *nema-5-30r- NEMA 5-30R *nema-5-50r- NEMA 5-50R *nema-6-15r- NEMA 6-15R *nema-6-20r- NEMA 6-20R *nema-6-30r- NEMA 6-30R *nema-6-50r- NEMA 6-50R *nema-10-30r- NEMA 10-30R *nema-10-50r- NEMA 10-50R *nema-14-20r- NEMA 14-20R *nema-14-30r- NEMA 14-30R *nema-14-50r- NEMA 14-50R *nema-14-60r- NEMA 14-60R *nema-15-15r- NEMA 15-15R *nema-15-20r- NEMA 15-20R *nema-15-30r- NEMA 15-30R *nema-15-50r- NEMA 15-50R *nema-15-60r- NEMA 15-60R *nema-l1-15r- NEMA L1-15R *nema-l5-15r- NEMA L5-15R *nema-l5-20r- NEMA L5-20R *nema-l5-30r- NEMA L5-30R *nema-l5-50r- NEMA L5-50R *nema-l6-15r- NEMA L6-15R *nema-l6-20r- NEMA L6-20R *nema-l6-30r- NEMA L6-30R *nema-l6-50r- NEMA L6-50R *nema-l10-30r- NEMA L10-30R *nema-l14-20r- NEMA L14-20R *nema-l14-30r- NEMA L14-30R *nema-l14-50r- NEMA L14-50R *nema-l14-60r- NEMA L14-60R *nema-l15-20r- NEMA L15-20R *nema-l15-30r- NEMA L15-30R *nema-l15-50r- NEMA L15-50R *nema-l15-60r- NEMA L15-60R *nema-l21-20r- NEMA L21-20R *nema-l21-30r- NEMA L21-30R *nema-l22-20r- NEMA L22-20R *nema-l22-30r- NEMA L22-30R *CS6360C- CS6360C *CS6364C- CS6364C *CS8164C- CS8164C *CS8264C- CS8264C *CS8364C- CS8364C *CS8464C- CS8464C *ita-e- ITA Type E (CEE 7/5) *ita-f- ITA Type F (CEE 7/3) *ita-g- ITA Type G (BS 1363) *ita-h- ITA Type H *ita-i- ITA Type I *ita-j- ITA Type J *ita-k- ITA Type K *ita-l- ITA Type L (CEI 23-50) *ita-m- ITA Type M (BS 546) *ita-n- ITA Type N *ita-o- ITA Type O *ita-multistandard- ITA Multistandard *usb-a- USB Type A *usb-micro-b- USB Micro B *usb-c- USB Type C *molex-micro-fit-1x2- Molex Micro-Fit 1x2 *molex-micro-fit-2x2- Molex Micro-Fit 2x2 *molex-micro-fit-2x3- Molex Micro-Fit 2x3 *molex-micro-fit-2x4- Molex Micro-Fit 2x4 *dc-terminal- DC Terminal *eaton-c39- Eaton C39 *hdot-cx- HDOT Cx *saf-d-grid- Saf-D-Grid *neutrik-powercon-20a- Neutrik powerCON (20A) *neutrik-powercon-32a- Neutrik powerCON (32A) *neutrik-powercon-true1- Neutrik powerCON TRUE1 *neutrik-powercon-true1-top- Neutrik powerCON TRUE1 TOP *ubiquiti-smartpower- Ubiquiti SmartPower *hardwired- Hardwired *other- Other
status: Option<Status>enabled- Enabled *disabled- Disabled *faulty- Faulty
color: Option<Box<BulkCableRequestColor>>power_port: Option<Option<Box<BulkPowerOutletRequestPowerPort>>>feed_leg: Option<Option<FeedLeg>>A- A *B- B *C- C
description: Option<String>mark_connected: Option<bool>Treat as if a cable is connected
owner: Option<Option<Box<AsnRangeRequestOwner>>>custom_fields: Option<HashMap<String, Value>>Implementations
Sourceimpl PatchedBulkPowerOutletRequest
impl PatchedBulkPowerOutletRequest
Sourcepub fn new(id: i32) -> PatchedBulkPowerOutletRequest
pub fn new(id: i32) -> PatchedBulkPowerOutletRequest
Adds an owner field for models which have a ForeignKey to users.Owner.