pub struct PatchedBulkTableConfigRequest {
pub id: i32,
pub object_type: Option<String>,
pub table: Option<String>,
pub name: Option<String>,
pub description: Option<String>,
pub user: Option<Option<i32>>,
pub weight: Option<i32>,
pub enabled: Option<bool>,
pub shared: Option<bool>,
pub columns: Option<Vec<String>>,
pub ordering: Option<Option<Vec<String>>>,
}Expand description
PatchedBulkTableConfigRequest : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: i32object_type: Option<String>table: Option<String>name: Option<String>description: Option<String>user: Option<Option<i32>>weight: Option<i32>enabled: Option<bool>columns: Option<Vec<String>>ordering: Option<Option<Vec<String>>>Implementations
Sourceimpl PatchedBulkTableConfigRequest
impl PatchedBulkTableConfigRequest
Sourcepub fn new(id: i32) -> PatchedBulkTableConfigRequest
pub fn new(id: i32) -> PatchedBulkTableConfigRequest
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)