pub struct PatchedBulkTokenRequest {
pub id: i32,
pub version: Option<i32>,
pub user: Option<Box<BookmarkRequestUser>>,
pub description: Option<String>,
pub expires: Option<Option<String>>,
pub last_used: Option<Option<String>>,
pub enabled: Option<bool>,
pub write_enabled: Option<bool>,
pub pepper_id: Option<Option<i32>>,
pub token: Option<String>,
}Expand description
PatchedBulkTokenRequest : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: i32version: Option<i32>1- v1 *2- v2
user: Option<Box<BookmarkRequestUser>>description: Option<String>expires: Option<Option<String>>last_used: Option<Option<String>>enabled: Option<bool>Disable to temporarily revoke this token without deleting it.
write_enabled: Option<bool>Permit create/update/delete operations using this token
pepper_id: Option<Option<i32>>ID of the cryptographic pepper used to hash the token (v2 only)
token: Option<String>Implementations
Sourceimpl PatchedBulkTokenRequest
impl PatchedBulkTokenRequest
Sourcepub fn new(id: i32) -> PatchedBulkTokenRequest
pub fn new(id: i32) -> PatchedBulkTokenRequest
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)