pub struct PatchedBulkVmInterfaceRequest {Show 18 fields
pub id: i32,
pub virtual_machine: Option<Box<BulkVmInterfaceRequestVirtualMachine>>,
pub name: Option<String>,
pub enabled: Option<bool>,
pub parent: Option<Option<Box<NestedVmInterfaceRequest>>>,
pub bridge: Option<Option<Box<NestedVmInterfaceRequest>>>,
pub mtu: Option<Option<i32>>,
pub primary_mac_address: Option<Option<Box<BulkInterfaceRequestPrimaryMacAddress>>>,
pub description: Option<String>,
pub mode: Option<Mode>,
pub untagged_vlan: Option<Option<Box<BulkInterfaceRequestUntaggedVlan>>>,
pub tagged_vlans: Option<Vec<i32>>,
pub qinq_svlan: Option<Option<Box<BulkInterfaceRequestUntaggedVlan>>>,
pub vlan_translation_policy: Option<Option<Box<BulkInterfaceRequestVlanTranslationPolicy>>>,
pub vrf: Option<Option<Box<BulkIpAddressRequestVrf>>>,
pub owner: Option<Option<Box<AsnRangeRequestOwner>>>,
pub tags: Option<Vec<NestedTagRequest>>,
pub custom_fields: Option<HashMap<String, Value>>,
}Expand description
PatchedBulkVmInterfaceRequest : Adds an owner field for models which have a ForeignKey to users.Owner.
Fields
id: i32virtual_machine: Option<Box<BulkVmInterfaceRequestVirtualMachine>>name: Option<String>enabled: Option<bool>parent: Option<Option<Box<NestedVmInterfaceRequest>>>bridge: Option<Option<Box<NestedVmInterfaceRequest>>>mtu: Option<Option<i32>>primary_mac_address: Option<Option<Box<BulkInterfaceRequestPrimaryMacAddress>>>description: Option<String>mode: Option<Mode>access- Access *tagged- Tagged *tagged-all- Tagged (All) *q-in-q- Q-in-Q (802.1ad)
untagged_vlan: Option<Option<Box<BulkInterfaceRequestUntaggedVlan>>>tagged_vlans: Option<Vec<i32>>qinq_svlan: Option<Option<Box<BulkInterfaceRequestUntaggedVlan>>>vlan_translation_policy: Option<Option<Box<BulkInterfaceRequestVlanTranslationPolicy>>>vrf: Option<Option<Box<BulkIpAddressRequestVrf>>>owner: Option<Option<Box<AsnRangeRequestOwner>>>custom_fields: Option<HashMap<String, Value>>Implementations
Sourceimpl PatchedBulkVmInterfaceRequest
impl PatchedBulkVmInterfaceRequest
Sourcepub fn new(id: i32) -> PatchedBulkVmInterfaceRequest
pub fn new(id: i32) -> PatchedBulkVmInterfaceRequest
Adds an owner field for models which have a ForeignKey to users.Owner.