pub struct PatchedConfigContextRequest {Show 21 fields
pub name: Option<String>,
pub weight: Option<i32>,
pub profile: Option<Option<Box<ConfigContextRequestProfile>>>,
pub description: Option<String>,
pub is_active: Option<bool>,
pub regions: Option<Vec<i32>>,
pub site_groups: Option<Vec<i32>>,
pub sites: Option<Vec<i32>>,
pub locations: Option<Vec<i32>>,
pub device_types: Option<Vec<i32>>,
pub roles: Option<Vec<i32>>,
pub platforms: Option<Vec<i32>>,
pub cluster_types: Option<Vec<i32>>,
pub cluster_groups: Option<Vec<i32>>,
pub clusters: Option<Vec<i32>>,
pub tenant_groups: Option<Vec<i32>>,
pub tenants: Option<Vec<i32>>,
pub owner: Option<Option<Box<AsnRangeRequestOwner>>>,
pub tags: Option<Vec<String>>,
pub data_source: Option<Box<ConfigContextProfileRequestDataSource>>,
pub data: Option<Option<Value>>,
}Expand description
PatchedConfigContextRequest : Adds an owner field for models which have a ForeignKey to users.Owner.
Fields
name: Option<String>weight: Option<i32>profile: Option<Option<Box<ConfigContextRequestProfile>>>description: Option<String>is_active: Option<bool>regions: Option<Vec<i32>>site_groups: Option<Vec<i32>>sites: Option<Vec<i32>>locations: Option<Vec<i32>>device_types: Option<Vec<i32>>roles: Option<Vec<i32>>platforms: Option<Vec<i32>>cluster_types: Option<Vec<i32>>cluster_groups: Option<Vec<i32>>clusters: Option<Vec<i32>>tenant_groups: Option<Vec<i32>>tenants: Option<Vec<i32>>owner: Option<Option<Box<AsnRangeRequestOwner>>>data_source: Option<Box<ConfigContextProfileRequestDataSource>>data: Option<Option<Value>>Implementations
Sourceimpl PatchedConfigContextRequest
impl PatchedConfigContextRequest
Sourcepub fn new() -> PatchedConfigContextRequest
pub fn new() -> PatchedConfigContextRequest
Adds an owner field for models which have a ForeignKey to users.Owner.