pub struct PatchedCustomLinkRequest {
pub object_types: Option<Vec<String>>,
pub name: Option<String>,
pub enabled: Option<bool>,
pub link_text: Option<String>,
pub link_url: Option<String>,
pub weight: Option<i32>,
pub group_name: Option<String>,
pub button_class: Option<ButtonClass>,
pub new_window: Option<bool>,
pub owner: Option<Option<Box<AsnRangeRequestOwner>>>,
}Expand description
PatchedCustomLinkRequest : Adds an owner field for models which have a ForeignKey to users.Owner.
Fields
object_types: Option<Vec<String>>name: Option<String>enabled: Option<bool>link_text: Option<String>Jinja2 template code for link text
link_url: Option<String>Jinja2 template code for link URL
weight: Option<i32>group_name: Option<String>Links with the same group will appear as a dropdown menu
The class of the first link in a group will be used for the dropdown button * default - Default * blue - Blue * indigo - Indigo * purple - Purple * pink - Pink * red - Red * orange - Orange * yellow - Yellow * green - Green * teal - Teal * cyan - Cyan * gray - Gray * black - Black * white - White * ghost-dark - Link
new_window: Option<bool>Force link to open in a new window
owner: Option<Option<Box<AsnRangeRequestOwner>>>Implementations
Sourceimpl PatchedCustomLinkRequest
impl PatchedCustomLinkRequest
Sourcepub fn new() -> PatchedCustomLinkRequest
pub fn new() -> PatchedCustomLinkRequest
Adds an owner field for models which have a ForeignKey to users.Owner.