pub struct PatchedWebhookRequest {Show 13 fields
pub name: Option<String>,
pub description: Option<String>,
pub payload_url: Option<String>,
pub http_method: Option<HttpMethod>,
pub http_content_type: Option<String>,
pub additional_headers: Option<String>,
pub body_template: Option<String>,
pub secret: Option<String>,
pub ssl_verification: Option<bool>,
pub ca_file_path: Option<Option<String>>,
pub custom_fields: Option<HashMap<String, Value>>,
pub owner: Option<Option<Box<AsnRangeRequestOwner>>>,
pub tags: Option<Vec<NestedTagRequest>>,
}Expand description
PatchedWebhookRequest : Adds an owner field for models which have a ForeignKey to users.Owner.
Fields
name: Option<String>description: Option<String>payload_url: Option<String>This URL will be called using the HTTP method defined when the webhook is called. Must be http:// or https://. Jinja2 template processing is supported (with the same context as the request body) for part or all of the URL.
http_method: Option<HttpMethod>GET- GET *POST- POST *PUT- PUT *PATCH- PATCH *DELETE- DELETE
http_content_type: Option<String>The complete list of official content types is available here (https://www.iana.org/assignments/media-types/media-types.xhtml).
additional_headers: Option<String>User-supplied HTTP headers to be sent with the request in addition to the HTTP content type. Headers should be defined in the format Name: Value. Jinja2 template processing is supported with the same context as the request body (below). When interpolating untrusted data (such as object attributes) into a header value, apply the header_safe filter to guard against HTTP header injection, e.g. X-Object: {{ data.name | header_safe }}.
body_template: Option<String>Jinja2 template for a custom request body. If blank, a JSON object representing the change will be included. Available context data includes: event, model, timestamp, username, request_id, and data.
secret: Option<String>When provided, the request will include a X-Hook-Signature header containing a HMAC hex digest of the payload body using the secret as the key. The secret is not transmitted in the request.
ssl_verification: Option<bool>Enable SSL certificate verification. Disable with caution!
ca_file_path: Option<Option<String>>The specific CA certificate file to use for SSL verification. Leave blank to use the system defaults.
custom_fields: Option<HashMap<String, Value>>owner: Option<Option<Box<AsnRangeRequestOwner>>>Implementations
Sourceimpl PatchedWebhookRequest
impl PatchedWebhookRequest
Sourcepub fn new() -> PatchedWebhookRequest
pub fn new() -> PatchedWebhookRequest
Adds an owner field for models which have a ForeignKey to users.Owner.