pub struct PatchedWritableConsoleServerPortRequest {
pub device: Option<Box<BriefInterfaceRequestDevice>>,
pub module: Option<Option<Box<ConsolePortRequestModule>>>,
pub name: Option<String>,
pub label: Option<String>,
pub type: Option<Option<RHashType>>,
pub speed: Option<Option<Speed>>,
pub description: Option<String>,
pub mark_connected: Option<bool>,
pub owner: Option<Option<Box<AsnRangeRequestOwner>>>,
pub tags: Option<Vec<NestedTagRequest>>,
pub custom_fields: Option<HashMap<String, Value>>,
}Expand description
PatchedWritableConsoleServerPortRequest : Adds an owner field for models which have a ForeignKey to users.Owner.
Fields
device: Option<Box<BriefInterfaceRequestDevice>>module: Option<Option<Box<ConsolePortRequestModule>>>name: Option<String>label: Option<String>Physical label
type: Option<Option<RHashType>>Physical port type * de-9 - DE-9 * db-25 - DB-25 * rj-11 - RJ-11 * rj-12 - RJ-12 * rj-45 - RJ-45 * mini-din-8 - Mini-DIN 8 * usb-a - USB Type A * usb-b - USB Type B * usb-c - USB Type C * usb-mini-a - USB Mini A * usb-mini-b - USB Mini B * usb-micro-a - USB Micro A * usb-micro-b - USB Micro B * usb-micro-ab - USB Micro AB * other - Other
speed: Option<Option<Speed>>Port speed in bits per second * 1200 - 1200 bps * 2400 - 2400 bps * 4800 - 4800 bps * 9600 - 9600 bps * 19200 - 19.2 kbps * 38400 - 38.4 kbps * 57600 - 57.6 kbps * 115200 - 115.2 kbps
description: Option<String>mark_connected: Option<bool>Treat as if a cable is connected
owner: Option<Option<Box<AsnRangeRequestOwner>>>custom_fields: Option<HashMap<String, Value>>Implementations
Sourceimpl PatchedWritableConsoleServerPortRequest
impl PatchedWritableConsoleServerPortRequest
Sourcepub fn new() -> PatchedWritableConsoleServerPortRequest
pub fn new() -> PatchedWritableConsoleServerPortRequest
Adds an owner field for models which have a ForeignKey to users.Owner.