pub struct PatchedWritableCustomFieldChoiceSetRequest {
pub name: Option<String>,
pub description: Option<String>,
pub base_choices: Option<Option<BaseChoices>>,
pub extra_choices: Option<Vec<Vec<Value>>>,
pub choice_colors: Option<ChoiceColors>,
pub order_alphabetically: Option<bool>,
pub owner: Option<Option<Box<AsnRangeRequestOwner>>>,
}Expand description
PatchedWritableCustomFieldChoiceSetRequest : Adds an owner field for models which have a ForeignKey to users.Owner.
Fields
name: Option<String>description: Option<String>base_choices: Option<Option<BaseChoices>>Base set of predefined choices (optional) * IATA - IATA (Airport codes) * ISO_3166 - ISO 3166 (Country codes) * UN_LOCODE - UN/LOCODE (Location codes)
extra_choices: Option<Vec<Vec<Value>>>choice_colors: Option<ChoiceColors>order_alphabetically: Option<bool>Choices are automatically ordered alphabetically
owner: Option<Option<Box<AsnRangeRequestOwner>>>Implementations
Sourceimpl PatchedWritableCustomFieldChoiceSetRequest
impl PatchedWritableCustomFieldChoiceSetRequest
Sourcepub fn new() -> PatchedWritableCustomFieldChoiceSetRequest
pub fn new() -> PatchedWritableCustomFieldChoiceSetRequest
Adds an owner field for models which have a ForeignKey to users.Owner.