pub struct ScriptModule {
pub id: Option<i32>,
pub display: Option<String>,
pub file_path: Option<String>,
pub created: Option<String>,
pub last_updated: Option<Option<String>>,
}Expand description
ScriptModule : Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)
Fields
id: Option<i32>display: Option<String>file_path: Option<String>created: Option<String>last_updated: Option<Option<String>>Implementations
Sourceimpl ScriptModule
impl ScriptModule
Sourcepub fn new() -> ScriptModule
pub fn new() -> ScriptModule
Extends the built-in ModelSerializer to enforce calling full_clean() on a copy of the associated instance during validation. (DRF does not do this by default; see https://github.com/encode/django-rest-framework/issues/3144)