pub struct VmInterface {Show 28 fields
pub id: Option<i32>,
pub url: Option<String>,
pub display_url: Option<String>,
pub display: Option<String>,
pub virtual_machine: Box<BriefVirtualMachine>,
pub name: String,
pub enabled: Option<bool>,
pub parent: Option<Option<Box<NestedVmInterface>>>,
pub bridge: Option<Option<Box<NestedVmInterface>>>,
pub mtu: Option<Option<i32>>,
pub mac_address: Option<Option<String>>,
pub primary_mac_address: Option<Option<Box<BriefMacAddress>>>,
pub mac_addresses: Option<Option<Vec<BriefMacAddress>>>,
pub description: Option<String>,
pub mode: Option<Box<InterfaceMode>>,
pub untagged_vlan: Option<Option<Box<BriefVlan>>>,
pub tagged_vlans: Option<Vec<Vlan>>,
pub qinq_svlan: Option<Option<Box<BriefVlan>>>,
pub vlan_translation_policy: Option<Option<Box<BriefVlanTranslationPolicy>>>,
pub vrf: Option<Option<Box<BriefVrf>>>,
pub l2vpn_termination: Option<Option<Box<BriefL2VpnTermination>>>,
pub owner: Option<Option<Box<BriefOwner>>>,
pub tags: Option<Vec<NestedTag>>,
pub custom_fields: Option<HashMap<String, Value>>,
pub created: Option<Option<String>>,
pub last_updated: Option<Option<String>>,
pub count_ipaddresses: Option<i32>,
pub count_fhrp_groups: Option<i32>,
}Expand description
VmInterface : Adds an owner field for models which have a ForeignKey to users.Owner.
Fields
id: Option<i32>url: Option<String>display_url: Option<String>display: Option<String>virtual_machine: Box<BriefVirtualMachine>name: Stringenabled: Option<bool>parent: Option<Option<Box<NestedVmInterface>>>bridge: Option<Option<Box<NestedVmInterface>>>mtu: Option<Option<i32>>mac_address: Option<Option<String>>primary_mac_address: Option<Option<Box<BriefMacAddress>>>mac_addresses: Option<Option<Vec<BriefMacAddress>>>description: Option<String>mode: Option<Box<InterfaceMode>>untagged_vlan: Option<Option<Box<BriefVlan>>>tagged_vlans: Option<Vec<Vlan>>qinq_svlan: Option<Option<Box<BriefVlan>>>vlan_translation_policy: Option<Option<Box<BriefVlanTranslationPolicy>>>vrf: Option<Option<Box<BriefVrf>>>l2vpn_termination: Option<Option<Box<BriefL2VpnTermination>>>owner: Option<Option<Box<BriefOwner>>>custom_fields: Option<HashMap<String, Value>>created: Option<Option<String>>last_updated: Option<Option<String>>count_ipaddresses: Option<i32>count_fhrp_groups: Option<i32>Implementations
Sourceimpl VmInterface
impl VmInterface
Sourcepub fn new(virtual_machine: BriefVirtualMachine, name: String) -> VmInterface
pub fn new(virtual_machine: BriefVirtualMachine, name: String) -> VmInterface
Adds an owner field for models which have a ForeignKey to users.Owner.